==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/items/tool/MarkerToolItems.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.tool;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.ToolBar;
import org.eclipse.swt.widgets.ToolItem;
import org.herac.tuxguitar.gui.SystemImages;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.marker.AddMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoFirstMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoLastMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoNextMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoPreviousMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.ListMarkersAction;
import org.herac.tuxguitar.gui.items.ItemContainer;
/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class MarkerToolItems  implements ItemContainer{
    public static final String NAME = "MARKER_ITEMS";
    
    private ToolBar toolBar;
	private ToolItem add;
	private ToolItem list;
    private ToolItem first;
	private ToolItem last;
	private ToolItem previous;
	private ToolItem next;
		
    public MarkerToolItems(ToolBar toolBar){
        this.toolBar = toolBar;
    }
   
    public void showItems(){     
        //--ADD--
        this.add = new ToolItem(toolBar, SWT.PUSH);
        this.add.setImage(SystemImages.MARKER_ADD);
        this.add.addSelectionListener(TuxGuitar.instance().getAction(AddMarkerAction.NAME));

        //--LIST--
        this.list = new ToolItem(toolBar, SWT.PUSH);
        this.list.setImage(SystemImages.MARKER_LIST);
        this.list.addSelectionListener(TuxGuitar.instance().getAction(ListMarkersAction.NAME));        
        
        //--SEPARATOR--
        new ToolItem(toolBar, SWT.SEPARATOR);        
        
        //--FIRST--
        this.first = new ToolItem(toolBar, SWT.PUSH);
        this.first.setImage(SystemImages.MARKER_FIRST);
        this.first.addSelectionListener(TuxGuitar.instance().getAction(GoFirstMarkerAction.NAME));        

        //--PREVIOUS--
        this.previous = new ToolItem(toolBar, SWT.PUSH);
        this.previous.setImage(SystemImages.MARKER_PREVIOUS);
        this.previous.addSelectionListener(TuxGuitar.instance().getAction(GoPreviousMarkerAction.NAME));        
        
        //--PREVIOUS--
        this.next = new ToolItem(toolBar, SWT.PUSH);
        this.next.setImage(SystemImages.MARKER_NEXT);
        this.next.addSelectionListener(TuxGuitar.instance().getAction(GoNextMarkerAction.NAME));        
        
        //--LAST--
        this.last = new ToolItem(toolBar, SWT.PUSH);
        this.last.setImage(SystemImages.MARKER_LAST);
        this.last.addSelectionListener(TuxGuitar.instance().getAction(GoLastMarkerAction.NAME));  

        this.loadProperties();
    }
 
    
    
    public void update(){    
    }
    
    public void loadProperties(){
        this.add.setToolTipText(TuxGuitar.getProperty("marker.add"));
        this.list.setToolTipText(TuxGuitar.getProperty("marker.list"));
        this.first.setToolTipText(TuxGuitar.getProperty("marker.first"));
        this.last.setToolTipText(TuxGuitar.getProperty("marker.last"));
        this.previous.setToolTipText(TuxGuitar.getProperty("marker.previous"));
        this.next.setToolTipText(TuxGuitar.getProperty("marker.next")); 
    }        
}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/items/tool/MarkerToolItems.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.tool;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.ToolBar;
import org.eclipse.swt.widgets.ToolItem;
import org.herac.tuxguitar.gui.SystemImages;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.marker.AddMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoFirstMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoLastMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoNextMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoPreviousMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.ListMarkersAction;
import org.herac.tuxguitar.gui.items.ToolItems;
/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class MarkerToolItems  extends ToolItems{
    public static final String NAME = "marker.items";
    
    private ToolBar toolBar;
	private ToolItem add;
	private ToolItem list;
    private ToolItem first;
	private ToolItem last;
	private ToolItem previous;
	private ToolItem next;
		
    public MarkerToolItems(){
    	super(NAME);
    }
   
    public void showItems(ToolBar toolBar){
    	this.toolBar = toolBar;         
        //--ADD--
        this.add = new ToolItem(toolBar, SWT.PUSH);
        this.add.setImage(SystemImages.MARKER_ADD);
        this.add.addSelectionListener(TuxGuitar.instance().getAction(AddMarkerAction.NAME));

        //--LIST--
        this.list = new ToolItem(toolBar, SWT.PUSH);
        this.list.setImage(SystemImages.MARKER_LIST);
        this.list.addSelectionListener(TuxGuitar.instance().getAction(ListMarkersAction.NAME));        
        
        //--SEPARATOR--
        new ToolItem(toolBar, SWT.SEPARATOR);        
        
        //--FIRST--
        this.first = new ToolItem(toolBar, SWT.PUSH);
        this.first.setImage(SystemImages.MARKER_FIRST);
        this.first.addSelectionListener(TuxGuitar.instance().getAction(GoFirstMarkerAction.NAME));        

        //--PREVIOUS--
        this.previous = new ToolItem(toolBar, SWT.PUSH);
        this.previous.setImage(SystemImages.MARKER_PREVIOUS);
        this.previous.addSelectionListener(TuxGuitar.instance().getAction(GoPreviousMarkerAction.NAME));        
        
        //--PREVIOUS--
        this.next = new ToolItem(toolBar, SWT.PUSH);
        this.next.setImage(SystemImages.MARKER_NEXT);
        this.next.addSelectionListener(TuxGuitar.instance().getAction(GoNextMarkerAction.NAME));        
        
        //--LAST--
        this.last = new ToolItem(toolBar, SWT.PUSH);
        this.last.setImage(SystemImages.MARKER_LAST);
        this.last.addSelectionListener(TuxGuitar.instance().getAction(GoLastMarkerAction.NAME));  

        this.loadProperties();
    }
 
    
    
    public void update(){    
    }
    
    public void loadProperties(){
        this.add.setToolTipText(TuxGuitar.getProperty("marker.add"));
        this.list.setToolTipText(TuxGuitar.getProperty("marker.list"));
        this.first.setToolTipText(TuxGuitar.getProperty("marker.first"));
        this.last.setToolTipText(TuxGuitar.getProperty("marker.last"));
        this.previous.setToolTipText(TuxGuitar.getProperty("marker.previous"));
        this.next.setToolTipText(TuxGuitar.getProperty("marker.next")); 
    }        
}
